package com.sun.org.apache.xerces.internal.impl.validation;

import java.util.Iterator;

public final class ConfigurableValidationState extends ValidationState
{
    private boolean fIdIdrefChecking;
    private boolean fUnparsedEntityChecking;
    
    public ConfigurableValidationState() {
        this.fIdIdrefChecking = true;
        this.fUnparsedEntityChecking = true;
    }
    
    public void setIdIdrefChecking(boolean setting) {
        this.fIdIdrefChecking = setting;
    }
    
    public void setUnparsedEntityChecking(boolean setting) {
        this.fUnparsedEntityChecking = setting;
    }
    
    @Override
    public Iterator checkIDRefID() {
        return this.fIdIdrefChecking ? super.checkIDRefID() : null;
    }
    
    @Override
    public boolean isIdDeclared(String name) {
        return this.fIdIdrefChecking && super.isIdDeclared(name);
    }
    
    @Override
    public boolean isEntityDeclared(String name) {
        return !this.fUnparsedEntityChecking || super.isEntityDeclared(name);
    }
    
    @Override
    public boolean isEntityUnparsed(String name) {
        return !this.fUnparsedEntityChecking || super.isEntityUnparsed(name);
    }
    
    @Override
    public void addId(String name) {
        if (this.fIdIdrefChecking) {
            super.addId(name);
        }
    }
    
    @Override
    public void addIdRef(String name) {
        if (this.fIdIdrefChecking) {
            super.addIdRef(name);
        }
    }
}
